==> tdm_2.0.0.tar.gz: tdm/R/all.Thecrss.R <==
all.Thecrss<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------\n")
     cat("    --Theophylline CR input data information--       \n")
     note_for_Thecrss_input()
     cat("-----------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     ThecrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                    
     ThecrSSpar<-edit(ThecrSSpar)                                                                                                                     
     ThecrSSpar<-ycheck(ThecrSSpar) 
     cat("\n")                                                                                                                   
     Thecr.ss(ThecrSSpar[8,2],ThecrSSpar[7,2],ThecrSSpar[6,2],ThecrSSpar[3,2],ThecrSSpar[2,2],ThecrSSpar[5,2],ThecrSSpar[1,2],ThecrSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------\n")
     cat("    --Theophylline CR output data information--            \n")
     note_for_Thecr_output()
     cat("-----------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(1,ThecrSSpar[6,2],ThecrSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")     
     show(coutput)
     cat("\n")   
     Thecr.more()                          
}

==> tdm_2.2.2.tar.gz: tdm/R/all.Thecrss.R <==
all.Thecrss<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------\n")
     cat("    --Theophylline CR input data information--       \n")
     note_for_Thecrss_input()
     cat("-----------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     ThecrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                    
     ThecrSSpar<-edit(ThecrSSpar)                                                                                                                     
##     ThecrSSpar<-ycheck(ThecrSSpar) 
     cat("\n")                                                                                                                   
     Thecr.ss(ThecrSSpar[8,2],ThecrSSpar[7,2],ThecrSSpar[6,2],ThecrSSpar[3,2],ThecrSSpar[2,2],ThecrSSpar[5,2],ThecrSSpar[1,2],ThecrSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------\n")
     cat("    --Theophylline CR output data information--            \n")
     note_for_Thecr_output()
     cat("-----------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(1,ThecrSSpar[6,2],ThecrSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")     
     show(coutput)
     cat("\n")   
     Thecr.more()                          
}
